@@ -182,6 +182,10 @@ class Editor(QMainWindow):
     def current_tag(self, for_position_sync=True):
         return self.editor.current_tag(for_position_sync=for_position_sync)
 
+    @property
+    def highlighter(self):
+        return self.editor.highlighter
+
     @property
     def number_of_lines(self):
         return self.editor.blockCount()
