@@ -206,7 +206,7 @@ class OpenWithHandler(object):  # {{{
         else:
             m.addSeparator()
             m.addAction(_('Add other application for %s files...') % fmt.upper(), partial(self.choose_open_with, file_name, fmt))
-            m.addAction(_('Edit Open With applications...'), partial(edit_programs, fmt, file_name))
+            m.addAction(_('Edit Open with applications...'), partial(edit_programs, fmt, self))
             menu.addMenu(m)
             menu.ow = m
 
@@ -661,7 +661,10 @@ class FileList(QTreeWidget, OpenWithHandler):
             move_to_start = question_dialog(self, _('Not first item'), _(
                 '%s is not the first text item. You should only mark the'
                 ' first text item as cover. Do you want to make it the'
-                ' first item?') % elided_text(name))
+                ' first item?') % elided_text(name),
+                skip_dialog_name='edit-book-mark-as-titlepage-move-confirm',
+                skip_dialog_skip_precheck=False
+            )
         self.mark_requested.emit(name, 'titlepage:%r' % move_to_start)
 
     def keyPressEvent(self, ev):
@@ -789,9 +792,9 @@ class FileList(QTreeWidget, OpenWithHandler):
     def dropEvent(self, event):
         with self:
             text = self.categories['text']
-            pre_drop_order = {text.child(i):i for i in range(text.childCount())}
+            pre_drop_order = {text.child(i).data(0, NAME_ROLE):i for i in range(text.childCount())}
             super(FileList, self).dropEvent(event)
-            current_order = {text.child(i):i for i in range(text.childCount())}
+            current_order = {text.child(i).data(0, NAME_ROLE):i for i in range(text.childCount())}
             if current_order != pre_drop_order:
                 order = []
                 for child in (text.child(i) for i in range(text.childCount())):
