@@ -7,6 +7,20 @@ from __future__ import absolute_import, division, print_function, unicode_litera
 from polyglot.builtins import is_py3
 
 if is_py3:
-    from plistlib import loads, dumps, Data  # noqa
+    from plistlib import loads, dumps  # noqa
+
+    def unwrap_bytes(x):
+        return x
+
+    def wrap_bytes(x):
+        return x
 else:
     from plistlib import readPlistFromString as loads, writePlistToString as dumps, Data  # noqa
+
+    def unwrap_bytes(x):
+        if isinstance(x, Data):
+            x = x.data
+        return x
+
+    def wrap_bytes(x):
+        return Data(x)
